@@ -147,5 +147,5 @@ def startParsing(adf, debug=False, runReplacers=True, bulletDecor=None):
     result = parse(adf)                                         #Do the Parsing
     if runReplacers:                                            #Run Replacers
         for r in replacers:        
-            result=result.replace(r, ' ')    
+            result=result.replace(r, '\n')    
     return result                                               #Return result
